==> radish-bdd-0.2.7.tar.gz: radish-bdd-0.2.7/README.md <==
# radish - the root from red to green
> Awesome python BDD tool http://radish-bdd.io

***

[![PyPI](https://img.shields.io/pypi/l/radish-bdd.svg)]()
[![Build Status](https://travis-ci.org/radish-bdd/radish.svg?branch=master)](https://travis-ci.org/radish-bdd/radish)
[![codecov.io](https://codecov.io/github/radish-bdd/radish/coverage.svg?branch=master)](https://codecov.io/github/radish-bdd/radish?branch=master)
[![Code Health](https://landscape.io/github/radish-bdd/radish/master/landscape.svg?style=flat)](https://landscape.io/github/radish-bdd/radish/master)
[![PyPI version](https://badge.fury.io/py/radish-bdd.svg)](https://badge.fury.io/py/radish-bdd)
[![PyPI](https://img.shields.io/pypi/pyversions/radish-bdd.svg)]()
[![PyPI](https://img.shields.io/pypi/wheel/radish-bdd.svg)]()
[![PyPI](https://img.shields.io/pypi/dm/radish-bdd.svg)](https://github.com/radish-bdd/radish)

**License**: MIT <br>
**Supported Python versions**: 2.7, 3.3, 3.4, 3.5

***

# What is radish?

radish is a Behavior Driven Development tool completely written in python. It supports all *gherkin* language features. In addition to that, radish implements a few *unconventional* BDD features such as **Preconditions**, **Scenario Loops**, **Variables** and **Expressions**.

# Installation

radish is available as `pip` package. As soon as all dependencies are available as `pip wheel` radish will be too.

```bash
pip install radish-bdd
```

**Note**: Make sure you have enough privileges to install radish on your system.

# Getting started

radish is very easy to use. Take the 5 minutes and follow the *Getting started* instruction on the radish website: http://radish-bdd.io/#gettingstarted

# Documentation

The whole documentation of radish is available here: http://radish.readthedocs.org/en/latest/quicktutorial.html

# Contribution

Yes, we are looking for some contributors and people who spread out a word about radish. Help us to improve these piece of software. You don't know what to do?
Just have a look at the Issues or create a new one.

==> radish-bdd-0.2.9.tar.gz: radish-bdd-0.2.9/README.md <==
# radish - the root from red to green
> Awesome python BDD tool http://radish-bdd.io

***

[![PyPI](https://img.shields.io/pypi/l/radish-bdd.svg)]()
[![Build Status](https://travis-ci.org/radish-bdd/radish.svg?branch=master)](https://travis-ci.org/radish-bdd/radish)
[![codecov.io](https://codecov.io/github/radish-bdd/radish/coverage.svg?branch=master)](https://codecov.io/github/radish-bdd/radish?branch=master)
[![Code Health](https://landscape.io/github/radish-bdd/radish/master/landscape.svg?style=flat)](https://landscape.io/github/radish-bdd/radish/master)
[![PyPI version](https://badge.fury.io/py/radish-bdd.svg)](https://badge.fury.io/py/radish-bdd)
[![PyPI](https://img.shields.io/pypi/pyversions/radish-bdd.svg)]()
[![PyPI](https://img.shields.io/pypi/wheel/radish-bdd.svg)]()
[![PyPI](https://img.shields.io/pypi/dm/radish-bdd.svg)](https://github.com/radish-bdd/radish)

**License**: MIT <br>
**Supported Python versions**: 2.7, 3.3, 3.4, 3.5

***

# What is radish?

radish is a Behavior Driven Development tool completely written in python. It supports all *gherkin* language features. In addition to that, radish implements a few *unconventional* BDD features such as **Preconditions**, **Scenario Loops**, **Variables** and **Expressions**.

# Installation

radish is available as `pip` package:

```bash
pip install radish-bdd
```

**Note**: Make sure you have enough privileges to install radish on your system.

# Getting started

radish is very easy to use. Take the 5 minutes and follow the *Getting started* instruction on the radish website: http://radish-bdd.io/#gettingstarted

# Documentation

The whole documentation of radish is available here: http://radish.readthedocs.org/en/latest/quicktutorial.html

# Contribution

Yes, we are looking for some contributors and people who spread out a word about radish. Help us to improve these piece of software. You don't know what to do?
Just have a look at the Issues or create a new one.
